@@ -51,11 +51,16 @@ class RPMWriter(upack.write.Writer):
     def write(self, ctx, package):
         ctx.push(self.context())
         ctx.push(package)
+        if ctx.get_from_ctx('epoch'):
+            epoch_line = 'Epoch:          {epoch}\n'
+        else:
+            epoch_line = ''
         pkg = ctx.format(
 '''Name:           {name}
 Version:        {version}
 Release:        {release}{dist}
-Summary:        {summary}
+''' + epoch_line +
+'''Summary:        {summary}
 
 License:        {license}
 URL:            {homepage}
